=============
xepmts-server
=============


.. image:: https://img.shields.io/pypi/v/xepmts_server.svg
        :target: https://pypi.python.org/pypi/xepmts_server

.. image:: https://img.shields.io/travis/jmosbacher/xepmts_server.svg
        :target: https://travis-ci.com/jmosbacher/xepmts_server

.. image:: https://readthedocs.org/projects/xepmts-server/badge/?version=latest
        :target: https://xepmts-server.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Server for the xepmts api


* Free software: MIT
* Documentation: https://xepmts-server.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `briggySmalls/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`briggySmalls/cookiecutter-pypackage`: https://github.com/briggySmalls/cookiecutter-pypackage
